==> peg-e_1.2.1.orig.tar.gz: peg-e-1.2.1/translations/pege_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Game Over</source>
        <translation>Žaidimas Baigtas</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos Kalba&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="172"/>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="172"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="37"/>
        <location filename="../src/window.cpp" line="233"/>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="56"/>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="58"/>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="59"/>
        <source>&amp;Restart Game</source>
        <translation>Žaisti iš naujo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="60"/>
        <source>&amp;Details</source>
        <translation>Iš&amp;samiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>Quit</source>
        <translation>Baigti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="65"/>
        <source>&amp;Move</source>
        <translation>&amp;Judesiai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="67"/>
        <source>&amp;Undo</source>
        <translation>An&amp;uliuoti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="71"/>
        <source>&amp;Redo</source>
        <translation>Pe&amp;rdaryti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="75"/>
        <source>&amp;Appearance</source>
        <translation>Išv&amp;aizda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <source>Blue</source>
        <translation>Mėlyna</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="79"/>
        <source>Charcoal</source>
        <translation>Anglies</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>Green</source>
        <translation>Žalia</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="81"/>
        <source>Midnight</source>
        <translation>Vidurnakčio</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="82"/>
        <source>Plum</source>
        <translation>Slyvos</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="83"/>
        <source>Red</source>
        <translation>Raudona</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="84"/>
        <source>Yellow</source>
        <translation>Geltona</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="102"/>
        <source>Custom...</source>
        <translation>Tinkinta...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="104"/>
        <source>&amp;Settings</source>
        <translation>Nu&amp;statymai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="105"/>
        <source>Application &amp;Language...</source>
        <translation>Programos Ka&amp;lba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="107"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="110"/>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="148"/>
        <source>New Game</source>
        <translation>Naujas Žaidimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="152"/>
        <location filename="../src/window.cpp" line="212"/>
        <source>Original</source>
        <translation>Originalus</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="153"/>
        <location filename="../src/window.cpp" line="205"/>
        <source>Branch</source>
        <translation>Šaka</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="154"/>
        <location filename="../src/window.cpp" line="208"/>
        <source>Line</source>
        <translation>Linija</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="164"/>
        <source>Random</source>
        <translation>Atsitiktinis</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>Difficulty:</source>
        <translation>Sunkumas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="175"/>
        <source>Seed:</source>
        <translation>Išdėstymas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="192"/>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="192"/>
        <source>Do you want to restart?</source>
        <translation>Ar norite pradėti iš naujo?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="215"/>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="215"/>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algoritmas:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Sunkumas:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Išdėstymas:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="230"/>
        <source>About Peg-E</source>
        <translation>Apie Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="234"/>
        <source>Peg elimination game</source>
        <translation>Kamštelių šalinimo žaidimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="235"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorinės Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="237"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Naudoja piktogramas iš &lt;a href=%1&gt;Oxygen&lt;/a&gt; piktogramų temos</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="238"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Panaudota pagal &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>

==> peg-e_1.3.4.orig.tar.gz: peg-e-1.3.4/translations/pege_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Žaidimas baigtas</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>Žaisti iš naujo</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>Iš&amp;samiau</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Baigti</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Judesiai</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>An&amp;uliuoti</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Pe&amp;rdaryti</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>Išv&amp;aizda</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Mėlyna</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>Anglies</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Žalia</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>Vidurnakčio</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>Slyvos</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Raudona</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Geltona</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Tinkinta...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Nu&amp;statymai</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Originalus</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>Šaka</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linija</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Atsitiktinis</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>Sunkumas:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Išdėstymas:</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>Ar norite pradėti iš naujo?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algoritmas:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Sunkumas:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Išdėstymas:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>Apie Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>Kamštelių šalinimo žaidimas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Naudoja piktogramas iš &lt;a href=%1&gt;Oxygen&lt;/a&gt; piktogramų temos</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Panaudota pagal &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>
